# NumiConveri

## Usage

For more detailed usage instructions and examples, please refer to the [documentation](https://github.com/PYthonCoder1128/numiconveri/wiki).

## License

This project is licensed under the MIT License - see the [LICENSE](https://github.com/PYthonCoder1128/numiconveri?tab=License-1-ov-file) file for details.
